@@ -46,7 +46,7 @@ class MCDA:
         # define state labels if not exists
         if criteria_labels == []:
             for s in range(0, len(alt_data[0])):
-                state_label.append("C" + str(s+1))
+                criteria_labels.append("C" + str(s+1))
 
         # define alternative labels if not exists
         if alt_labels == []:
